@@ -1,9 +1,12 @@
-use sha2::{Sha224, Sha256, Sha384, Sha512, Sha512Trunc224, Sha512Trunc256};
+use sha2::{Sha224, Sha256, Sha384, Sha512};
 
 use super::DigestCreate;
 
-fn create(digest: &mut impl sha2::Digest, input: &[u8]) -> String {
-    digest.update(input);
+fn create<D: sha2::Digest + sha2::digest::FixedOutputReset>(
+    digest: &mut D,
+    input: &[u8],
+) -> String {
+    sha2::Digest::update(digest, input);
     base64::encode(&digest.finalize_reset())
 }
 
@@ -38,19 +41,3 @@ impl DigestCreate for Sha512 {
         create(self, input)
     }
 }
-
-impl DigestCreate for Sha512Trunc224 {
-    const NAME: &'static str = "SHA-512-224";
-
-    fn compute(&mut self, input: &[u8]) -> String {
-        create(self, input)
-    }
-}
-
-impl DigestCreate for Sha512Trunc256 {
-    const NAME: &'static str = "SHA-512-256";
-
-    fn compute(&mut self, input: &[u8]) -> String {
-        create(self, input)
-    }
-}
